Italian ECQ Italy, Modena September 27th 2003 68 players Iñaki Puigdollers Deck Name: Menú: Paella y Tortilla de Patata (Menu: Paella & Potato Omelette) Description: !toreador module with Tzimisce supportto develope a quiet game while bloating and hitting with the WG. As I have said the deck could be defined as a bloat deck with high bleeding potential while is the time. Defend your ground, generate pool and play as many minions and whever prepared offer Paella for everyone!, The potato omelette will send whoever who tries to interdict to torpor... . Crypt (12 cards, min=14, max=23, avg=4.75) ------------------------------------------ 2x Jost Werner 6 AUS PRE ani Toreador antitribu:2 2x Creamy Jade 5 PRE aus cel vic Toreador antitribu:3 2x Rose, The 5 PRE VIC aus Tzimisce:3 1x Sheila Mezarin 6 AUS PRE cel for Toreador antitribu:2 1x Elizabeth Westcott 5 AUS ani cel vic Tzimisce:3 1x Mercy, Knight Inquisitor 5 AUS cel dom pre Toreador antitribu:2 1x Remilliard, Devout Crusader 4 AUS pre Toreador antitribu:2 1x Lolita 3 for pre Toreador antitribu:2 1x Carter 2 cel Toreador antitribu:2 Library (90 cards) Master (15) 1x Anarch Troublemaker 1x Art of Pain, The 2x Blood Doll 1x Direct Intervention 1x Hungry Coyote, The -- after the tournament I have decided that the Jakes are enough for this and that my minions have always better actions to do rather than hunt. I would change it for a Pentex "anti helena/Lucas halton/..." Subversion 3x Jake Washington -- He is perfect for both the WG and let my midcaps eat if hungry 4x Palla Grande 2x Vicissitude Action (29) 9x Art Scam 3x Embrace, The -- extremely useful for bleed and multiple action as rescuing from torpor/eating alive/rush walls 9x Enchant Kindred 3x Entrancement -- To defend my omelettes, for bleeding or for an extrarecruitment if ever able, this card is so great 5x Summoning, The -- key, essential, If you summon a WG and the action is blocked you don't lose the Meat machine so you could try it later, and it also multiplies the number of getting a WG from my library Ally (4) 4x War Ghoul Retainer (4) 1x J. S. Simmons, Esq. 2x Marijava Ghoul -- exceptionals, There are 15 pressence action cards and this makes 'em more efficient, but he is also meat for the WG god 1x Tasha Morgan Action Modifier (12) 6x Change of Target -- for the embraces aswell and the Ghouls if an evil killer vamps untaps suddenly while attacking 6x Changeling Action Modifier/Combat (5) 5x Plasmic Form Reaction (14) 2x Forced Awakening -- helps to dry my vamps before drinking a full Jake for supper 4x My Enemy's Enemy 4x Telepathic Misdirection 4x Wake with Evening's Freshness Combat (7) 7x Majesty